@@ -3,7 +3,7 @@ from bson import encode
 from .channel import Channel
 from .message import Message
 from .error import AuthException, PasscodeException
-from .utils import get_xvc, getBookingData, getCheckInData, Packet, CryptoManager, Writer
+from .utils import get_xvc, Packet, CryptoManager, Writer
 class HTTP:
     def __init__(self, client, device_uuid):
         self.__session_key = ""
