@@ -1,9 +1,7 @@
 import json
-
-
 import hashlib
 import requests
-
+from .utils import File
 
 class Message:
     def __init__(self, http, channel, body):
@@ -63,7 +61,7 @@ class Message:
     async def kick(self):
         return await self.channel.kickMember(self.authorId)
 
-    async def __sendPhoto(self, data, w, h):
+    async def __sendFile(self, data, w, h, datatype):
         path, key, url = await self.__http.upload(data, "image/jpeg", self.authorId)
         return await self.channel.forwardChat(
             "",
@@ -78,20 +76,16 @@ class Message:
                     "s": len(data),
                     "w": w,
                     "h": h,
-                    "mt": "image/jpeg",
+                    "mt": datatype,
                 }
             ),
             2,
         )
 
-    async def send_image_path(self, path, w, h):
-        with open(path, "rb") as f:
+    async def send_file(self, _file, w, h):
+        if not isinstance(_file, File):
+            raise TypeError
+        with open(_file.path, "rb") as f:
             data = f.read()
 
-        return await self.__sendPhoto(data, w, h)
-
-    async def send_image_url(self, url, w, h):
-        r = requests.get(url)
-        r.raise_for_status()
-
-        return await self.__sendPhoto(r.content, w, h)
+        return await self.__sendFile(data, w, h, _file.datatype)
